<?php $TRANSLATIONS = array(
"Wrong calendar" => "Kalender salah",
"Timezone changed" => "Zona waktu telah diubah",
"Invalid request" => "Permintaan tidak sah",
"Calendar" => "Kalender",
"Birthday" => "Ulang tahun",
"Business" => "Usaha",
"Clients" => "Klien",
"Deliverer" => "Pengirim",
"Holidays" => "Hari libur",
"Journey" => "Perjalanan",
"Meeting" => "Rapat",
"Other" => "Lainnya",
"Questions" => "Pertanyaan",
"Does not repeat" => "Tidak akan mengulangi",
"Daily" => "Harian",
"Weekly" => "Mingguan",
"Every Weekday" => "Setiap Hari Minggu",
"Bi-Weekly" => "Dwi-mingguan",
"Monthly" => "Bulanan",
"Yearly" => "Tahunan",
"All day" => "Semua Hari",
"Title" => "Judul",
"Week" => "Minggu",
"Month" => "Bulan",
"Today" => "Hari ini",
"Download" => "Unduh",
"Edit" => "Sunting",
"Edit calendar" => "Sunting kalender",
"Displayname" => "Namatampilan",
"Active" => "Aktif",
"Calendar color" => "Warna kalender",
"Submit" => "Sampaikan",
"Edit an event" => "Sunting agenda",
"Title of the Event" => "Judul Agenda",
"Category" => "Kategori",
"All Day Event" => "Agenda di Semua Hari",
"From" => "Dari",
"To" => "Ke",
"Location" => "Lokasi",
"Location of the Event" => "Lokasi Agenda",
"Description" => "Deskripsi",
"Description of the Event" => "Deskripsi dari Agenda",
"Repeat" => "Ulangi",
"Create a new event" => "Buat agenda baru",
"Timezone" => "Zonawaktu"
);
